"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var React = _interopRequireWildcard(require("react"));
var _reactVirtualized = require("react-virtualized");
var _defaultProps = _interopRequireDefault(require("./default-props"));
var _styledComponents = require("./styled-components");
var _locale = require("../locale");
var _styledComponents2 = require("../menu/styled-components");
var _overrides = require("../helpers/overrides");
var _utils = require("./utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); } /*
Copyright (c) Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
CountrySelectDropdown.defaultProps = {
  maxDropdownHeight: _defaultProps.default.maxDropdownHeight,
  overrides: {}
};
function CountrySelectDropdown(props) {
  const {
    $country: country,
    $forwardedRef: forwardedRef,
    $maxDropdownHeight: maxDropdownHeight,
    $mapIsoToLabel: mapIsoToLabel,
    $noResultsMsg: noResultsMsg,
    $overrides: overrides
  } = props;
  const [Container, containerProps] = (0, _overrides.getOverrides)(overrides.CountrySelectDropdown, _styledComponents.StyledCountrySelectDropdownContainer);
  const [ListItem, listItemProps] = (0, _overrides.getOverrides)(overrides.CountrySelectDropdownListItem, _styledComponents.StyledCountrySelectDropdownListItem);
  const [FlagColumn, flagColumnProps] = (0, _overrides.getOverrides)(overrides.CountrySelectDropdownFlagColumn, _styledComponents.StyledCountrySelectDropdownFlagColumn);
  const [FlagContainer, flagContainerProps] = (0, _overrides.getOverrides)(overrides.FlagContainer, _styledComponents.StyledFlagContainer);
  const [NameColumn, nameColumnProps] = (0, _overrides.getOverrides)(overrides.CountrySelectDropdownNameColumn, _styledComponents.StyledCountrySelectDropdownNameColumn);
  const [Dialcode, dialcodeProps] = (0, _overrides.getOverrides)(overrides.CountrySelectDropdownDialcodeColumn, _styledComponents.StyledCountrySelectDropdownDialcodeColumn);
  const [EmptyState, emptyStateProps] = (0, _overrides.getOverrides)(overrides.EmptyState, _styledComponents2.StyledEmptyState);

  // Handle no results, likely from filtering
  if (!props.children.length) {
    return /*#__PURE__*/React.createElement(_locale.LocaleContext.Consumer, null, locale => /*#__PURE__*/React.createElement(EmptyState, emptyStateProps, noResultsMsg || locale.menu.noResultsMsg));
  }
  const children = React.Children.toArray(props.children);
  const scrollIndex = Math.min(children.findIndex(opt =>
  // @ts-expect-error todo(flow->ts) type issue introduced in react 17
  opt.props.item.id === country.id) + 5, children.length - 1);
  return /*#__PURE__*/React.createElement(Container, _extends({
    ref: forwardedRef,
    $height: maxDropdownHeight
  }, containerProps), /*#__PURE__*/React.createElement(_reactVirtualized.AutoSizer, null, ({
    height,
    width
  }) => {
    return /*#__PURE__*/React.createElement(_reactVirtualized.List, {
      role: "listbox",
      height: height,
      width: width,
      rowCount: children.length,
      rowHeight: 42,
      scrollToIndex: scrollIndex,
      rowRenderer: ({
        index,
        key,
        style
      }) => {
        // resetMenu and getItemLabel should not end up on native html elements
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        const {
          item,
          resetMenu,
          getItemLabel,
          ...rest
        } =
        // @ts-expect-error todo(flow->ts) type issue introduced in react 17
        children[index].props;
        const {
          id: iso,
          label,
          dialCode
        } = item;
        return /*#__PURE__*/React.createElement(ListItem, _extends({
          key: key,
          style: style,
          item: item
        }, rest, listItemProps, {
          "data-iso": iso
        }), /*#__PURE__*/React.createElement(FlagColumn, flagColumnProps, /*#__PURE__*/React.createElement(FlagContainer, _extends({
          $iso: iso,
          "data-iso": iso
        }, flagContainerProps), (0, _utils.iso2FlagEmoji)(iso))), /*#__PURE__*/React.createElement(NameColumn, nameColumnProps, mapIsoToLabel ? mapIsoToLabel(iso) : label), /*#__PURE__*/React.createElement(Dialcode, dialcodeProps, dialCode));
      }
    });
  }));
}
const CountrySelectDropdownFwd = /*#__PURE__*/React.forwardRef((props, ref) => /*#__PURE__*/React.createElement(CountrySelectDropdown, _extends({}, props, {
  $forwardedRef: ref
})));
CountrySelectDropdownFwd.displayName = 'CountrySelectDropdownFwd';
var _default = exports.default = CountrySelectDropdownFwd;